import { Socket, Server } from "socket.io";
import {TSocket} from "../types/TSocket";
import {Character} from "@prisma/client";
import CharacterRepository from "../repositories/CharacterRepository";
import {ZCharacterCreate} from "../types/zod/CharacterCreate";

export default function CharacterCreate(socket: TSocket, io: Server) {
    socket.on('character:create', async (data: any) => {
        // zod validate
        try {
            data = ZCharacterCreate.parse(data);

            let user_id = socket.user?.id as number;
            let character: Character = await CharacterRepository.create(user_id, data.name) as Character;
            let characters: Character[] = await CharacterRepository.getByUserId(user_id) as Character[];

            socket.emit('character:list', characters);
        } catch (error: any) {
            return socket.emit('notification', {error: error.errors[0].message});
        }
    });
}